from PIL import Image
import os


def compress(infile, outfile, target_kb, step=1):
    size = os.path.getsize(infile)/1024
    img = Image.open(infile)
    if size <= target_kb:
        img.save(outfile, quality=95)   # 质量 1到95,由低到高

    else:
        now_size = size
        qua = 95
        while now_size > target_kb:
            qua -= step
            if qua <= 1:
                break
            img.save(outfile, quality=qua)
            print(qua)
            now_size = os.path.getsize(outfile)/1024


if __name__ == '__main__':
    in_name = 'C:/lsc_files/blog-pictures/1.jpg'
    directory, suffix = os.path.splitext(in_name)       # 将路径和后缀分开
    out_name = '{}-out{}'.format(directory, suffix)     # 拼凑成新名字
    print(out_name)
    compress(in_name, out_name, 20)



"""
    大多数(nobody)女主喜好
"""
BaiJiaHui = {
    'like': {'服饰搭配', '古典乐', '古装片', '滑雪', '美容', '民谣', '萨克斯', '桑拿', '时尚', '天文', '西餐', '演唱会', '游戏', '瑜伽', '桌游', '温泉', '吉他',
             '游泳', '度假村', '网球', '美容'},
    'dislike': {'美食', '高抬腿'}
}

GaoShanShan = {
    'like': {'高山', '有氧跑', '海边休闲', '剪纸', '民宿', '拼图', '桑拿', '派对', '爱情片', '服饰搭配', '天文', '平板支撑', '度假村', '花滑', '古典乐', '滑雪',
             '跳水'},
    'dislike': {'烹饪', '综艺', '马术', '游乐园', '足球', '科技', '瑜伽', '纯音乐'}
}

ZhuChenXi = {
    'like': {'游泳', '健身操', '瑜伽', '星座', '时尚', '农家乐', '度假村', '露营', '剪纸', '小提琴', '美食', '闽菜', '烹饪', '模玩', '刷视频', '科技'},
    'dislike': {'剧本杀', '推理片', '古装片', '警匪片', '恐怖片', '纪录片', '奇幻片', '仰卧起坐', '平板支撑', '俯卧撑', '深蹲', '高抬腿', '登山', '羽毛球', '网球',
                '逛街', '花艺', '温泉', '钢琴', '手风琴', '吉他', '演唱会', '绘画', '高山', 'up主', '动物园', '花滑', '海边休闲', '乒乓', '舞蹈', '哲学',
                '摇滚乐'}
}

mapping = {1: BaiJiaHui, 2: GaoShanShan, 3: ZhuChenXi}

if __name__ == '__main__':
    print("请选择人物: 1.白嘉卉 2.高珊珊 3.朱晨希")
    obj = mapping[int(input())]

    while 1:
        hobby = input()
        if hobby in obj['like']:
            print('like')
        elif hobby in obj['dislike']:
            print('dislike')
        else:
            print('wrong')



# 16进制按字节转换为字符
def HexByte2Char(txt: str):
    chars = [chr(int(txt[i:i + 2], 16)) for i in range(0, len(txt), 2)]
    return ''.join(chars)


if __name__ == '__main__':
    txt = '52656164426f6172644944'
    print(HexByte2Char(txt))



import hashlib


def md5(path):
    try:
        with open(path, 'rb') as f:
            return hashlib.md5(f.read()).hexdigest()
    except:
        return 'fail to open file'


if __name__ == '__main__':
    while True:
        path = input('please input file path:')
        print(md5(path))



import re
import requests
from bs4 import BeautifulSoup
import json

DEFAULT_USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:108.0) Gecko/20100101 Firefox/108.0'


def getPage(url, encoding='utf-8') -> str:
    headers = {'User-Agent': DEFAULT_USER_AGENT}
    response = requests.get(url=url, headers=headers)
    print(response.status_code)
    content = response.content.decode(encoding=encoding)
    return content


def savePage(url: str, dest: str = './page.html', encoding='utf-8'):
    page = getPage(url=url, encoding=encoding)
    with open(dest, 'w', encoding=encoding) as fw:
        fw.write(page)


def download(url: str, dest: str, headers: dict):
    try:
        response = requests.get(url=url, headers=headers,
                                stream=True, verify=True)
        print(response.status_code)
        with open(dest, 'wb') as fw:
            for chunk in response.iter_content(1024):
                fw.write(chunk)
                fw.flush()  # 清空缓存
    except Exception as e:
        print("url下载错误: %s" % url)
        print(e)
    return


def bilibili(url: str, dest: str, audio_or_video: str):
    headers = {
        'User-Agent': DEFAULT_USER_AGENT,
        "Origin": 'https://www.bilibili.com/',
        "Referer": 'https://www.bilibili.com/',
    }
    response = requests.get(url=url, headers=headers)
    soup = BeautifulSoup(response.text, 'lxml')
    video_url = ''
    audio_url = ''
    for i in range(len(soup('script'))):
        pattern = 'window.__playinfo__='
        if str(soup('script')[i].string)[:len(pattern)] == pattern:
            info = str(soup('script')[i].string)[len(pattern):]
            info_dict = json.loads(info)
            video_url = info_dict['data']['dash']['video'][0]['baseUrl']
            audio_url = info_dict['data']['dash']['audio'][0]['baseUrl']
            break
    if audio_or_video == 'audio':
        download(url=audio_url, dest=dest, headers=headers)
    if audio_or_video == 'video':
        download(url=video_url, dest=dest, headers=headers)
    return


def kugou(url, dest):
    """
        url = 'https://www.kugou.com/mixsong/49zyubb7.html?frombaidu#hash=04BBC1EC0A36C36457541588F0A6B337&album_id=3771
        4499&album_audio_id=258659363'
        address:
            https://wwwapi.kugou.com/yy/index.php?r=play/getdata&callback=jQuery19106392951916303002_1654082244006 // 固定
            &hash=13C62DD9569E717335EC282F8A38D837  // 可得
            &dfid=0R7vvH0Zd9bG4fCYat0Ad5ge&appid=1014&mid=c25d7ff99a965e5755984d727fccd663&platid=4   // 固定
            &album_id=970232    // 可得
            &album_audio_id=32130860  // 可得
    """
    # hashCode = 'hash=.*?&'
    # hashCode = re.findall(hashCode, url)[0]
    # album_id = 'album_id=[0-9]*'
    # album_id = re.findall(album_id, url)[0]
    # album_audio_id = 'album_audio_id.*?$'
    # album_audio_id = re.findall(album_audio_id, url)[0]

    hashCode = 'EBCCDE59F97BC06183F3B1A8502B7479'
    album_id = '2nc3vnfe'

    address = 'https://wwwapi.kugou.com/yy/index.php?r=play/getdata&callback=jQuery191063929519' \
              '16303002_1654082244006&' + hashCode + 'dfid=0R7vvH0Zd9bG4fCYat0Ad5ge&appid=1014&mid' \
                                                     '=c25d7ff99a965e5755984d727fccd663&platid=4&' + album_id
    print(address)

    headers = {
        'User-Agent': DEFAULT_USER_AGENT,
        "Origin": 'https://www.kugou.com/',
        "Referer": 'https://www.kugou.com/',
    }
    mp3 = "\"play_url\":\"https:.*?\""
    page = getPage(url=address)
    print(page)
    mp3 = re.findall("\"play_url\":\"https:.*?\"", page)[0][11:]
    print(mp3)
    mp3 = mp3.replace('\\', '')
    mp3 = mp3.replace('"', '')
    # print(mp3)
    download(url=mp3, dest=dest, headers=headers)
    return


if __name__ == '__main__':
    # print('hello world')
    # m = "https://www.bilibili.com/video/BV15841137Ge/"
    # bilibili(m, '1.mp3', 'audio')
    pass



"""
    这是一个文件处理的包，目前有的功能:
        splitBigFile: 将大文件按每个文件 linesPerFile 行分割成若干个小文件
"""


def splitBigFile(src: str, dest: str, linesPerFile=100000, encoding: str = 'utf-8'):
    suffix = src.split('.')[-1]
    with open(src, 'r', encoding=encoding) as fr:
        lineNum = 0
        fileNum = 0
        lines = []
        while 1:
            if lineNum < linesPerFile:
                line = fr.readline()
                if not line:
                    if lineNum == 0:
                        return
                    else:
                        with open(dest + '/split_file_' + str(fileNum) + '.' + suffix, 'w', encoding=encoding) as fw:
                            fw.writelines(lines)
                        return
                else:
                    lines.append(line)
                    lineNum += 1
            else:
                with open(dest + '/split_file_' + str(fileNum) + '.' + suffix, 'w', encoding=encoding) as fw:
                    fw.writelines(lines)
                lineNum = 0
                fileNum += 1
                lines = []



import tkinter as tk
from tkinter import ttk
import windnd
from tkinter import scrolledtext
from src.cli.fileMD5 import md5


class FileMD5(tk.Tk):
    def __init__(self):
        super().__init__()
        self.creat_window()
        self.create_widgets()
        self.grid()
        windnd.hook_dropfiles(self.text_10, func=self.drag_files)

    def creat_window(self):
        self.title('文件MD5计算')
        self.window_width = 800
        self.window_height = 200
        screen_width = self.winfo_screenwidth()
        screen_height = self.winfo_screenheight()
        x = (screen_width - self.window_width) // 2
        y = (screen_height - self.window_height) // 2
        self.geometry(f"{self.window_width}x{self.window_height}+{x}+{y}")

    def create_widgets(self):
        # row 0
        self.label_00 = tk.Label(self, text='拖放文件：')
        self.label_01 = ttk.Label(self, text='MD5值：')

        # row 1
        self.text_10 = scrolledtext.ScrolledText(self, width=50, height=10)
        self.text_11 = scrolledtext.ScrolledText(self, width=35, height=10)

    def grid(self):
        # row 0
        self.label_00.grid(row=0, column=0, sticky='w')
        self.label_01.grid(row=0, column=1, sticky='w')

        # row 1
        self.text_10.grid(row=1, column=0)
        self.text_11.grid(row=1, column=1)

    def drag_files(self, file_paths):
        for path in file_paths:
            path: bytes = path.decode()
            self.text_10.insert(tk.END, path + '\n')
            self.text_11.insert(tk.END, md5(path) + '\n')


if __name__ == '__main__':
    app = FileMD5()
    app.mainloop()



import tkinter as tk
from tkinter import ttk
from src.gui.fileMD5_gui import FileMD5


class App(tk.Tk):
    def __init__(self):
        super().__init__()
        self.create_window()
        self.create_widgets()
        self.grid()

    def create_window(self):
        self.title('文件处理工具')
        self.window_width = 600
        self.window_height = 400
        screen_width = self.winfo_screenwidth()
        screen_height = self.winfo_screenheight()
        x = (screen_width - self.window_width) // 2
        y = (screen_height - self.window_height) // 2
        self.geometry(f"{self.window_width}x{self.window_height}+{x}+{y}")

    def create_widgets(self):
        # row 0
        self.button_00 = ttk.Button(self, text='文件MD5计算', command=self.fileMD5)
        # self.button_01 = ttk.Button(self, text='', command=self.fileCut)

    def grid(self):
        # row 0
        self.button_00.grid(row=0, column=0)

    def fileMD5(self):
        subWin = FileMD5()
        subWin.attributes('-topmost', True)
        subWin.mainloop()


if __name__ == '__main__':
    app = App()
    app.mainloop()
